summaryrefslogtreecommitdiffstats
path: root/tdeui/tests
diff options
context:
space:
mode:
Diffstat (limited to 'tdeui/tests')
-rw-r--r--tdeui/tests/CMakeLists.txt14
-rw-r--r--tdeui/tests/Makefile.am32
-rw-r--r--tdeui/tests/itemcontainertest.cpp54
-rw-r--r--tdeui/tests/itemcontainertest.h12
-rw-r--r--tdeui/tests/kaboutdialogtest.cpp14
-rw-r--r--tdeui/tests/kactiontest.cpp38
-rw-r--r--tdeui/tests/kblendtest.cpp4
-rw-r--r--tdeui/tests/kbuttonboxtest.cpp4
-rw-r--r--tdeui/tests/kcharselecttest.cpp6
-rw-r--r--tdeui/tests/kcolordlgtest.cpp12
-rw-r--r--tdeui/tests/kcolortest.cpp4
-rw-r--r--tdeui/tests/kcomboboxtest.cpp14
-rw-r--r--tdeui/tests/kcompletiontest.cpp6
-rw-r--r--tdeui/tests/kdatepicktest.cpp8
-rw-r--r--tdeui/tests/kdatetimewidgettest.cpp8
-rw-r--r--tdeui/tests/kdatewidgettest.cpp8
-rw-r--r--tdeui/tests/kdesattest.cpp4
-rw-r--r--tdeui/tests/kdialogbasetest.cpp4
-rw-r--r--tdeui/tests/kdocktest.cpp4
-rw-r--r--tdeui/tests/kdockwidgetdemo.cpp12
-rw-r--r--tdeui/tests/kdockwidgettest.cpp10
-rw-r--r--tdeui/tests/kdualcolortest.cpp6
-rw-r--r--tdeui/tests/keditlistboxtest.cpp4
-rw-r--r--tdeui/tests/kedittest.cpp4
-rw-r--r--tdeui/tests/kgradienttest.cpp4
-rw-r--r--tdeui/tests/khashtest.cpp4
-rw-r--r--tdeui/tests/kinputdialogtest.cpp4
-rw-r--r--tdeui/tests/kjanuswidgettest.cpp4
-rw-r--r--tdeui/tests/kledtest.cpp4
-rw-r--r--tdeui/tests/klineeditdlgtest.cpp4
-rw-r--r--tdeui/tests/klineedittest.cpp20
-rw-r--r--tdeui/tests/klistviewtest.cpp39
-rw-r--r--tdeui/tests/kmainwindowrestoretest.h48
-rw-r--r--tdeui/tests/kmessageboxtest.cpp8
-rw-r--r--tdeui/tests/knuminputtest.cpp6
-rw-r--r--tdeui/tests/kpalettetest.cpp4
-rw-r--r--tdeui/tests/kpanelmenutest.cpp4
-rw-r--r--tdeui/tests/kpixmapregionselectordialogtest.cpp16
-rw-r--r--tdeui/tests/kprogresstest.cpp4
-rw-r--r--tdeui/tests/krulertest.cpp6
-rw-r--r--tdeui/tests/krulertest.h6
-rw-r--r--tdeui/tests/kseparatortest.cpp2
-rw-r--r--tdeui/tests/ksqueezedtextlabeltest.cpp4
-rw-r--r--tdeui/tests/kstatusbartest.cpp14
-rw-r--r--tdeui/tests/kstatusbartest.h6
-rw-r--r--tdeui/tests/ksystemtraytest.cpp4
-rw-r--r--tdeui/tests/ktabctltest.cpp6
-rw-r--r--tdeui/tests/ktabwidgettest.cpp8
-rw-r--r--tdeui/tests/ktextedittest.cpp4
-rw-r--r--tdeui/tests/ktimewidgettest.cpp8
-rw-r--r--tdeui/tests/kunbalancedgrdtest.cpp4
-rw-r--r--tdeui/tests/kwizardtest.cpp4
-rw-r--r--tdeui/tests/kwordwraptest.cpp4
-rw-r--r--tdeui/tests/kxmlguitest.cpp20
-rw-r--r--tdeui/tests/kxmlguitest.h2
-rw-r--r--tdeui/tests/kxmlguitest_part.rc2
-rw-r--r--tdeui/tests/tdeaccelgentest.cpp (renamed from tdeui/tests/kaccelgentest.cpp)10
-rw-r--r--tdeui/tests/tdeactiontest.cpp38
-rw-r--r--tdeui/tests/tdefontdialogtest.cpp (renamed from tdeui/tests/kfontdialogtest.cpp)16
-rw-r--r--tdeui/tests/tdelistviewtest.cpp39
-rw-r--r--tdeui/tests/tdemainwindowrestoretest.cpp (renamed from tdeui/tests/kmainwindowrestoretest.cpp)8
-rw-r--r--tdeui/tests/tdemainwindowrestoretest.h48
-rw-r--r--tdeui/tests/tdemainwindowtest.cpp (renamed from tdeui/tests/kmainwindowtest.cpp)10
-rw-r--r--tdeui/tests/tdemainwindowtest.h (renamed from tdeui/tests/kmainwindowtest.h)4
-rw-r--r--tdeui/tests/tdepopuptest.cpp (renamed from tdeui/tests/kpopuptest.cpp)10
-rw-r--r--tdeui/tests/tdespelltest.cpp (renamed from tdeui/tests/kspelltest.cpp)6
-rw-r--r--tdeui/tests/tdetoolbarlabelactiontest.cpp (renamed from tdeui/tests/ktoolbarlabelactiontest.cpp)24
-rw-r--r--tdeui/tests/tdetoolbarlabelactiontestui.rc (renamed from tdeui/tests/ktoolbarlabelactiontestui.rc)2
-rw-r--r--tdeui/tests/twindowtest.cpp36
-rw-r--r--tdeui/tests/twindowtest.h16
70 files changed, 415 insertions, 415 deletions
diff --git a/tdeui/tests/CMakeLists.txt b/tdeui/tests/CMakeLists.txt
index 9b3cc6568..719902623 100644
--- a/tdeui/tests/CMakeLists.txt
+++ b/tdeui/tests/CMakeLists.txt
@@ -27,21 +27,21 @@ set( test_PROGS
kcolortest kcolordlgtest kcomboboxtest kcompletiontest
kdatepicktest kdatewidgettest kdialogbasetest
kdockwidgetdemo kdockwidgettest
- kdualcolortest keditlistboxtest kfontdialogtest
+ kdualcolortest keditlistboxtest tdefontdialogtest
kgradienttest khashtest kdesattest
kledtest klineedittest klineeditdlgtest
kmessageboxtest knuminputtest
kpalettetest
- kpopuptest kprogresstest krulertest kseparatortest
+ tdepopuptest kprogresstest krulertest kseparatortest
kstatusbartest ktabctltest
kunbalancedgrdtest twindowtest kwizardtest
itemcontainertest kpanelmenutest kedittest
- kxmlguitest kaccelgentest ksystemtraytest klistviewtest
- ktextedittest kmainwindowtest kmainwindowrestoretest
- kactiontest kdatetimewidgettest ktimewidgettest
- kspelltest kinputdialogtest ktabwidgettest kwordwraptest
+ kxmlguitest tdeaccelgentest ksystemtraytest tdelistviewtest
+ ktextedittest tdemainwindowtest tdemainwindowrestoretest
+ tdeactiontest kdatetimewidgettest ktimewidgettest
+ tdespelltest kinputdialogtest ktabwidgettest kwordwraptest
kdocktest qxembedtest ksqueezedtextlabeltest
- kpixmapregionselectordialogtest kjanuswidgettest ktoolbarlabelactiontest
+ kpixmapregionselectordialogtest kjanuswidgettest tdetoolbarlabelactiontest
)
foreach( PROG ${test_PROGS} )
diff --git a/tdeui/tests/Makefile.am b/tdeui/tests/Makefile.am
index a7c0cb26d..361d437a9 100644
--- a/tdeui/tests/Makefile.am
+++ b/tdeui/tests/Makefile.am
@@ -26,21 +26,21 @@ check_PROGRAMS = kaboutdialogtest kblendtest kbuttonboxtest kcharselecttest \
kcolortest kcolordlgtest kcomboboxtest kcompletiontest \
kdatepicktest kdatewidgettest kdialogbasetest \
kdockwidgetdemo kdockwidgettest \
- kdualcolortest keditlistboxtest kfontdialogtest \
+ kdualcolortest keditlistboxtest tdefontdialogtest \
kgradienttest khashtest kdesattest\
kledtest klineedittest klineeditdlgtest \
kmessageboxtest knuminputtest \
kpalettetest \
- kpopuptest kprogresstest krulertest kseparatortest \
+ tdepopuptest kprogresstest krulertest kseparatortest \
kstatusbartest ktabctltest \
kunbalancedgrdtest twindowtest kwizardtest \
itemcontainertest kpanelmenutest kedittest \
- kxmlguitest kaccelgentest ksystemtraytest klistviewtest \
- ktextedittest kmainwindowtest kmainwindowrestoretest \
- kactiontest kdatetimewidgettest ktimewidgettest \
- kspelltest kinputdialogtest ktabwidgettest kwordwraptest \
+ kxmlguitest tdeaccelgentest ksystemtraytest tdelistviewtest \
+ ktextedittest tdemainwindowtest tdemainwindowrestoretest \
+ tdeactiontest kdatetimewidgettest ktimewidgettest \
+ tdespelltest kinputdialogtest ktabwidgettest kwordwraptest \
kdocktest qxembedtest ksqueezedtextlabeltest \
- kpixmapregionselectordialogtest kjanuswidgettest ktoolbarlabelactiontest
+ kpixmapregionselectordialogtest kjanuswidgettest tdetoolbarlabelactiontest
METASOURCES = AUTO
@@ -62,7 +62,7 @@ kdialogbasetest_SOURCES = kdialogbasetest.cpp
kdualcolortest_SOURCES = kdualcolortest.cpp
kedittest_SOURCES = kedittest.cpp
keditlistboxtest_SOURCES = keditlistboxtest.cpp
-kfontdialogtest_SOURCES = kfontdialogtest.cpp
+tdefontdialogtest_SOURCES = tdefontdialogtest.cpp
kgradienttest_SOURCES = kgradienttest.cpp
khashtest_SOURCES = khashtest.cpp
kledtest_SOURCES = kledtest.cpp
@@ -71,7 +71,7 @@ klineeditdlgtest_SOURCES = klineeditdlgtest.cpp
kmessageboxtest_SOURCES = kmessageboxtest.cpp
knuminputtest_SOURCES = knuminputtest.cpp
kpalettetest_SOURCES = kpalettetest.cpp
-kpopuptest_SOURCES = kpopuptest.cpp
+tdepopuptest_SOURCES = tdepopuptest.cpp
kprogresstest_SOURCES = kprogresstest.cpp
krulertest_SOURCES = krulertest.cpp
kseparatortest_SOURCES = kseparatortest.cpp
@@ -86,14 +86,14 @@ kpanelmenutest_SOURCES = kpanelmenutest.cpp
kdockwidgetdemo_SOURCES = kdockwidgetdemo.cpp
kdockwidgettest_SOURCES = kdockwidgettest.cpp
kxmlguitest_SOURCES = kxmlguitest.cpp
-kaccelgentest_SOURCES = kaccelgentest.cpp
+tdeaccelgentest_SOURCES = tdeaccelgentest.cpp
ksystemtraytest_SOURCES = ksystemtraytest.cpp
-klistviewtest_SOURCES = klistviewtest.cpp
+tdelistviewtest_SOURCES = tdelistviewtest.cpp
ktextedittest_SOURCES = ktextedittest.cpp
-kmainwindowtest_SOURCES = kmainwindowtest.cpp
-kmainwindowrestoretest_SOURCES = kmainwindowrestoretest.cpp
-kactiontest_SOURCES = kactiontest.cpp
-kspelltest_SOURCES = kspelltest.cpp
+tdemainwindowtest_SOURCES = tdemainwindowtest.cpp
+tdemainwindowrestoretest_SOURCES = tdemainwindowrestoretest.cpp
+tdeactiontest_SOURCES = tdeactiontest.cpp
+tdespelltest_SOURCES = tdespelltest.cpp
kinputdialogtest_SOURCES = kinputdialogtest.cpp
ktabwidgettest_SOURCES = ktabwidgettest.cpp
kwordwraptest_SOURCES = kwordwraptest.cpp
@@ -102,4 +102,4 @@ qxembedtest_SOURCES=qxembedtest.cpp
ksqueezedtextlabeltest_SOURCES = ksqueezedtextlabeltest.cpp
kjanuswidgettest_SOURCES = kjanuswidgettest.cpp
kpixmapregionselectordialogtest_SOURCES = kpixmapregionselectordialogtest.cpp
-ktoolbarlabelactiontest_SOURCES = ktoolbarlabelactiontest.cpp
+tdetoolbarlabelactiontest_SOURCES = tdetoolbarlabelactiontest.cpp
diff --git a/tdeui/tests/itemcontainertest.h b/tdeui/tests/itemcontainertest.h
index 86a356ab3..cb6cc3a51 100644
--- a/tdeui/tests/itemcontainertest.h
+++ b/tdeui/tests/itemcontainertest.h
@@ -3,9 +3,9 @@
#include <tqwidget.h>
-class KIconView;
-class KListView;
-class KListBox;
+class TDEIconView;
+class TDEListView;
+class TDEListBox;
class TQButtonGroup;
class TQLabel;
@@ -31,9 +31,9 @@ public slots:
void slotClicked( TQIconViewItem* ) { tqDebug("CLICK");}
void slotDoubleClicked( TQIconViewItem* ) { tqDebug("DOUBLE CLICK");}
protected:
- KIconView* m_pIconView;
- KListView* m_pListView;
- KListBox* m_pListBox;
+ TDEIconView* m_pIconView;
+ TDEListView* m_pListView;
+ TDEListBox* m_pListBox;
TQButtonGroup* m_pbgView;
TQButtonGroup* m_pbgMode;
diff --git a/tdeui/tests/kaboutdialogtest.cpp b/tdeui/tests/kaboutdialogtest.cpp
index 6103c6ba4..e0680b52f 100644
--- a/tdeui/tests/kaboutdialogtest.cpp
+++ b/tdeui/tests/kaboutdialogtest.cpp
@@ -8,19 +8,19 @@
* $Revision$
*/
-#include "kaboutdialog.h"
+#include "tdeaboutdialog.h"
// #include <kimgio.h>
#include <tqimage.h>
-#include <kapplication.h>
-#include <klocale.h>
+#include <tdeapplication.h>
+#include <tdelocale.h>
int main(int argc, char** argv)
{
- (void)new KApplication(argc, argv, "KAboutDialogTest");
+ (void)new TDEApplication(argc, argv, "TDEAboutDialogTest");
TQImage logo;
TQImage bg;
TQPixmap pix;
- KAboutDialog about;
+ TDEAboutDialog about;
// -----
// kimgioRegister();
if(logo.load("RayTracedGear.png"))
@@ -45,8 +45,8 @@ int main(int argc, char** argv)
// ("Cl&ose", "Close this dialog.",
// "<b>Close</b> the dialog<br>"
// "<i>(there are no settings to save).</i>");
- about.setCaption("KAboutDialog example");
- about.setVersion("KAboutDialog, Draft Study");
+ about.setCaption("TDEAboutDialog example");
+ about.setVersion("TDEAboutDialog, Draft Study");
about.setHelp("kdehelp/intro.html", "intro");
// ----- set the application author:
about.setAuthor
diff --git a/tdeui/tests/kactiontest.cpp b/tdeui/tests/kactiontest.cpp
deleted file mode 100644
index ea97883c8..000000000
--- a/tdeui/tests/kactiontest.cpp
+++ /dev/null
@@ -1,38 +0,0 @@
-
-#include <tqguardedptr.h>
-
-#include <kapplication.h>
-#include <kaction.h>
-
-#include <assert.h>
-
-int main( int argc, char **argv )
-{
- KApplication app( argc, argv, "kactiontest" );
-
- KActionCollection coll( static_cast<TQObject *>( 0 ) );
-
- TQGuardedPtr<KAction> action1 = new KRadioAction("test",0, &coll);
- TQGuardedPtr<KAction> action2 = new KRadioAction("test",0, &coll);
- TQGuardedPtr<KAction> action3 = new KRadioAction("test",0, &coll);
- TQGuardedPtr<KAction> action4 = new KRadioAction("test",0, &coll);
- TQGuardedPtr<KAction> action5 = new KRadioAction("test",0, &coll);
- TQGuardedPtr<KAction> action6 = new KRadioAction("test",0, &coll);
- TQGuardedPtr<KAction> action7 = new KRadioAction("test",0, &coll);
-
- coll.clear();
- assert( coll.isEmpty() );
-
- assert( action1.isNull() );
- assert( action2.isNull() );
- assert( action3.isNull() );
- assert( action4.isNull() );
- assert( action5.isNull() );
- assert( action6.isNull() );
- assert( action7.isNull() );
-
- return 0;
-}
-
-/* vim: et sw=4 ts=4
- */
diff --git a/tdeui/tests/kblendtest.cpp b/tdeui/tests/kblendtest.cpp
index 59a57dc6a..4672b76ee 100644
--- a/tdeui/tests/kblendtest.cpp
+++ b/tdeui/tests/kblendtest.cpp
@@ -1,5 +1,5 @@
#include "kblendtest.h"
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <kimageeffect.h>
#include <tqpainter.h>
#include <tqdatetime.h>
@@ -89,7 +89,7 @@ void KBlendWidget::paintEvent(TQPaintEvent */*ev*/)
int main(int argc, char **argv)
{
- KApplication app(argc, argv, "KBlendTest");
+ TDEApplication app(argc, argv, "KBlendTest");
KBlendWidget w;
app.setMainWidget(&w);
w.show();
diff --git a/tdeui/tests/kbuttonboxtest.cpp b/tdeui/tests/kbuttonboxtest.cpp
index 1773c47f9..c9eb1134b 100644
--- a/tdeui/tests/kbuttonboxtest.cpp
+++ b/tdeui/tests/kbuttonboxtest.cpp
@@ -16,7 +16,7 @@
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/
-#include <kapplication.h>
+#include <tdeapplication.h>
#include "kbuttonbox.h"
#include <tqlayout.h>
#include <tqlabel.h>
@@ -24,7 +24,7 @@
#include <tqpushbutton.h>
int main(int argc, char **argv) {
- KApplication a(argc, argv, "dummy");
+ TDEApplication a(argc, argv, "dummy");
// example 1
{
diff --git a/tdeui/tests/kcharselecttest.cpp b/tdeui/tests/kcharselecttest.cpp
index facd17bca..5ee4ee381 100644
--- a/tdeui/tests/kcharselecttest.cpp
+++ b/tdeui/tests/kcharselecttest.cpp
@@ -1,10 +1,10 @@
-#include <kapplication.h>
-#include <klocale.h>
+#include <tdeapplication.h>
+#include <tdelocale.h>
#include "kcharselect.h"
int main (int argc,char **argv)
{
- KApplication app( argc, argv, "kcharselecttest" );
+ TDEApplication app( argc, argv, "kcharselecttest" );
KCharSelect selector( 0, "char selector" );
selector.resize( selector.sizeHint() );
diff --git a/tdeui/tests/kcolordlgtest.cpp b/tdeui/tests/kcolordlgtest.cpp
index f372e6a96..dbe39484c 100644
--- a/tdeui/tests/kcolordlgtest.cpp
+++ b/tdeui/tests/kcolordlgtest.cpp
@@ -17,19 +17,19 @@
Boston, MA 02110-1301, USA.
*/
-#include <kapplication.h>
+#include <tdeapplication.h>
#include "kcolordialog.h"
-#include <kconfig.h>
-#include <klocale.h>
+#include <tdeconfig.h>
+#include <tdelocale.h>
int main( int argc, char *argv[] )
{
TQColor color;
- KLocale::setMainCatalogue("tdelibs");
+ TDELocale::setMainCatalogue("tdelibs");
TQApplication::setColorMode( TQApplication::CustomColors );
- KApplication a( argc, argv, "KColorDialogTest" );
- KConfig aConfig;
+ TDEApplication a( argc, argv, "KColorDialogTest" );
+ TDEConfig aConfig;
aConfig.setGroup( "KColorDialog-test" );
color = aConfig.readColorEntry( "Chosen" );
diff --git a/tdeui/tests/kcolortest.cpp b/tdeui/tests/kcolortest.cpp
index 68f50371b..243de265b 100644
--- a/tdeui/tests/kcolortest.cpp
+++ b/tdeui/tests/kcolortest.cpp
@@ -1,6 +1,6 @@
#include "kcolortest.h"
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <kimageeffect.h>
#include <stdio.h>
#include <tqdatetime.h>
@@ -160,7 +160,7 @@ int main(int argc, char **argv)
else
printf("Usage: %s [int_vs_fade | fullscreen [old_way]]\n ", argv[0]);
}
- KApplication *app = new KApplication(argc, argv, "KColorTest");
+ TDEApplication *app = new TDEApplication(argc, argv, "KColorTest");
KColorWidget w;
app->setMainWidget(&w);
w.show();
diff --git a/tdeui/tests/kcomboboxtest.cpp b/tdeui/tests/kcomboboxtest.cpp
index 44b849b44..d2b59a4c2 100644
--- a/tdeui/tests/kcomboboxtest.cpp
+++ b/tdeui/tests/kcomboboxtest.cpp
@@ -6,10 +6,10 @@
#include <assert.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <kdebug.h>
#include <kdialog.h>
-#include <klocale.h>
+#include <tdelocale.h>
#include <kiconloader.h>
#include <ksimpleconfig.h>
@@ -52,7 +52,7 @@ KComboBoxTest::KComboBoxTest(TQWidget* widget, const char* name )
m_ro = new KComboBox(hbox, "ReadOnlyCombo" );
lbl->setBuddy (m_ro);
- m_ro->setCompletionMode( KGlobalSettings::CompletionAuto );
+ m_ro->setCompletionMode( TDEGlobalSettings::CompletionAuto );
TQObject::connect (m_ro, TQT_SIGNAL(activated(int)), TQT_SLOT(slotActivated(int)));
TQObject::connect (m_ro, TQT_SIGNAL(activated(const TQString&)), TQT_SLOT (slotActivated(const TQString&)));
vbox->addWidget (hbox);
@@ -139,10 +139,10 @@ KComboBoxTest::KComboBoxTest(TQWidget* widget, const char* name )
// Setup konq's combobox
KSimpleConfig historyConfig( "konq_history" );
historyConfig.setGroup( "Location Bar" );
- KCompletion * s_pCompletion = new KCompletion;
- s_pCompletion->setOrder( KCompletion::Weighted );
+ TDECompletion * s_pCompletion = new TDECompletion;
+ s_pCompletion->setOrder( TDECompletion::Weighted );
s_pCompletion->setItems( historyConfig.readListEntry( "ComboContents" ) );
- s_pCompletion->setCompletionMode( KGlobalSettings::completionMode() );
+ s_pCompletion->setCompletionMode( TDEGlobalSettings::completionMode() );
m_konqc->setCompletionObject( s_pCompletion );
TQPixmap pix = SmallIcon("www");
@@ -217,7 +217,7 @@ void KComboBoxTest::quitApp()
int main ( int argc, char **argv)
{
- KApplication a(argc, argv, "kcomboboxtest");
+ TDEApplication a(argc, argv, "kcomboboxtest");
KComboBoxTest* t= new KComboBoxTest;
a.setMainWidget (t);
t->show ();
diff --git a/tdeui/tests/kcompletiontest.cpp b/tdeui/tests/kcompletiontest.cpp
index 3e60a0ddd..261534465 100644
--- a/tdeui/tests/kcompletiontest.cpp
+++ b/tdeui/tests/kcompletiontest.cpp
@@ -1,4 +1,4 @@
-#include <klocale.h>
+#include <tdelocale.h>
/****************************************************************************
** Form implementation generated from reading ui file './kcompletiontest.ui'
**
@@ -18,7 +18,7 @@
#include <tqtooltip.h>
#include <tqwhatsthis.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <klineedit.h>
#include <kcombobox.h>
/*
@@ -186,7 +186,7 @@ TQStringList Form1::defaultItems() const
int main(int argc, char **argv )
{
- KApplication app( argc, argv, "kcompletiontest" );
+ TDEApplication app( argc, argv, "kcompletiontest" );
Form1 *form = new Form1();
form->show();
diff --git a/tdeui/tests/kdatepicktest.cpp b/tdeui/tests/kdatepicktest.cpp
index bea01a434..8bdab90a4 100644
--- a/tdeui/tests/kdatepicktest.cpp
+++ b/tdeui/tests/kdatepicktest.cpp
@@ -1,12 +1,12 @@
#include "kdatepicker.h"
#include <tqlineedit.h>
-#include <kapplication.h>
-#include <klocale.h>
+#include <tdeapplication.h>
+#include <tdelocale.h>
int main(int argc, char** argv)
{
- KLocale::setMainCatalogue("tdelibs");
- KApplication app(argc, argv, "KDatePickertest");
+ TDELocale::setMainCatalogue("tdelibs");
+ TDEApplication app(argc, argv, "KDatePickertest");
KDatePicker picker;
app.setMainWidget(&picker);
picker.show();
diff --git a/tdeui/tests/kdatetimewidgettest.cpp b/tdeui/tests/kdatetimewidgettest.cpp
index ab55b0a32..f94a2a9f7 100644
--- a/tdeui/tests/kdatetimewidgettest.cpp
+++ b/tdeui/tests/kdatetimewidgettest.cpp
@@ -1,11 +1,11 @@
#include "kdatetimewidget.h"
-#include <kapplication.h>
-#include <klocale.h>
+#include <tdeapplication.h>
+#include <tdelocale.h>
int main(int argc, char** argv)
{
- KLocale::setMainCatalogue("tdelibs");
- KApplication app(argc, argv, "KDateTimeWidgettest");
+ TDELocale::setMainCatalogue("tdelibs");
+ TDEApplication app(argc, argv, "KDateTimeWidgettest");
KDateTimeWidget dateTimeWidget;
app.setMainWidget(&dateTimeWidget);
dateTimeWidget.show();
diff --git a/tdeui/tests/kdatewidgettest.cpp b/tdeui/tests/kdatewidgettest.cpp
index af75b42bc..22340b4c9 100644
--- a/tdeui/tests/kdatewidgettest.cpp
+++ b/tdeui/tests/kdatewidgettest.cpp
@@ -1,12 +1,12 @@
#include "kdatewidget.h"
#include <tqlineedit.h>
-#include <kapplication.h>
-#include <klocale.h>
+#include <tdeapplication.h>
+#include <tdelocale.h>
int main(int argc, char** argv)
{
- KLocale::setMainCatalogue("tdelibs");
- KApplication app(argc, argv, "KDateWidgettest");
+ TDELocale::setMainCatalogue("tdelibs");
+ TDEApplication app(argc, argv, "KDateWidgettest");
KDateWidget dateWidget;
app.setMainWidget(&dateWidget);
dateWidget.show();
diff --git a/tdeui/tests/kdesattest.cpp b/tdeui/tests/kdesattest.cpp
index 28f7d4cf2..8eab0b125 100644
--- a/tdeui/tests/kdesattest.cpp
+++ b/tdeui/tests/kdesattest.cpp
@@ -1,5 +1,5 @@
#include "kdesattest.h"
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <kimageeffect.h>
#include <tqpainter.h>
#include <tqdatetime.h>
@@ -55,7 +55,7 @@ void KDesatWidget::paintEvent(TQPaintEvent */*ev*/)
int main(int argc, char **argv)
{
- KApplication *app = new KApplication(argc, argv, "KDesatTest");
+ TDEApplication *app = new TDEApplication(argc, argv, "KDesatTest");
KDesatWidget w;
app->setMainWidget(&w);
w.show();
diff --git a/tdeui/tests/kdialogbasetest.cpp b/tdeui/tests/kdialogbasetest.cpp
index c3653b59f..7f8023bd2 100644
--- a/tdeui/tests/kdialogbasetest.cpp
+++ b/tdeui/tests/kdialogbasetest.cpp
@@ -1,4 +1,4 @@
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <kdialogbase.h>
#include <tqstring.h>
@@ -6,7 +6,7 @@
int main(int argc, char** argv)
{
- KApplication app(argc, argv, "DialogBaseTest");
+ TDEApplication app(argc, argv, "DialogBaseTest");
// -----
TQString text= // the explanation shown by the example dialog
"<center><h1>DialogBase Example</h1></center><hr><br>"
diff --git a/tdeui/tests/kdocktest.cpp b/tdeui/tests/kdocktest.cpp
index 84895c414..538e2b888 100644
--- a/tdeui/tests/kdocktest.cpp
+++ b/tdeui/tests/kdocktest.cpp
@@ -1,6 +1,6 @@
#include "kdocktest.h"
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <kiconloader.h>
#include <tqwidget.h>
@@ -54,7 +54,7 @@ DockTest::DockTest( TQWidget* parent )
int
main( int argc, char** argv )
{
- KApplication a( argc,argv, "docktest" );
+ TDEApplication a( argc,argv, "docktest" );
DockTest* ap = new DockTest();
ap->setCaption("DockWidget demo");
a.setMainWidget( ap );
diff --git a/tdeui/tests/kdockwidgetdemo.cpp b/tdeui/tests/kdockwidgetdemo.cpp
index 7847a6299..a922acf2d 100644
--- a/tdeui/tests/kdockwidgetdemo.cpp
+++ b/tdeui/tests/kdockwidgetdemo.cpp
@@ -19,8 +19,8 @@
#include <tqstrlist.h>
#include <tqpainter.h>
-#include <kconfig.h>
-#include <kapplication.h>
+#include <tdeconfig.h>
+#include <tdeapplication.h>
//#include <kimgio.h>
#include <stdlib.h>
@@ -81,7 +81,7 @@ static const char *preview_xpm[] = {
SFileDialog::SFileDialog( TQString initially, const TQStringList& filter, const char* name )
:TQDialog(0L,name,true)
{
- KConfig* config = kapp->config();
+ TDEConfig* config = kapp->config();
config->setGroup( TQString::fromLatin1("SFileDialogData:") + name );
if ( initially.isNull() ){
initially = config->readPathEntry( "InitiallyDir", TQDir::currentDirPath() );
@@ -166,7 +166,7 @@ void SFileDialog::dockChange()
SFileDialog::~SFileDialog()
{
- KConfig* config = kapp->config();
+ TDEConfig* config = kapp->config();
config->setGroup( TQString("SFileDialogData:") + name() );
config->writeEntry( "Bookmarks", fd->getBookmark() );
@@ -188,7 +188,7 @@ void SFileDialog::setDockDefaultPos( KDockWidget* d )
void SFileDialog::changeDir( const TQString& f )
{
if ( !f.isEmpty() ){
- KConfig* config = kapp->config();
+ TDEConfig* config = kapp->config();
config->setGroup( TQString("SFileDialogData:") + name() );
config->writePathEntry( "InitiallyDir", f );
}
@@ -768,7 +768,7 @@ TQString DirectoryView::selectedDir()
/**********************************************************************************************/
int main(int argc, char* argv[]) {
- KApplication app(argc,argv,"kdockwidgetdemo");
+ TDEApplication app(argc,argv,"kdockwidgetdemo");
#if 0
SFileDialog* openfile = new SFileDialog();
diff --git a/tdeui/tests/kdockwidgettest.cpp b/tdeui/tests/kdockwidgettest.cpp
index 74d8ecac4..aacac19a0 100644
--- a/tdeui/tests/kdockwidgettest.cpp
+++ b/tdeui/tests/kdockwidgettest.cpp
@@ -15,11 +15,11 @@
#include "kdockwidgettest.h"
#include <tqpushbutton.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <kiconloader.h>
#include <kstatusbar.h>
-#include <kmenubar.h>
-#include <ktoolbar.h>
+#include <tdemenubar.h>
+#include <tdetoolbar.h>
#include <tqvbox.h>
static const char*folder[]={
@@ -184,7 +184,7 @@ void DockApplication::initMenuBar()
void DockApplication::initToolBars()
{
TQPixmap p(folder);
- KToolBar* tool_bar_0 = toolBar(0);
+ TDEToolBar* tool_bar_0 = toolBar(0);
tool_bar_0->setFullSize(false);
tool_bar_0->insertButton( p, 1 );
tool_bar_0->insertButton(p, 2 );
@@ -242,7 +242,7 @@ void DockApplication::gSetPix2() {
}
int main(int argc, char* argv[]) {
- KApplication a(argc,argv, "kdockdemoapp1");
+ TDEApplication a(argc,argv, "kdockdemoapp1");
DockApplication* ap = new DockApplication("DockWidget demo");
ap->setCaption("DockWidget demo");
a.setMainWidget(ap);
diff --git a/tdeui/tests/kdualcolortest.cpp b/tdeui/tests/kdualcolortest.cpp
index 6fa2d1571..512bfc610 100644
--- a/tdeui/tests/kdualcolortest.cpp
+++ b/tdeui/tests/kdualcolortest.cpp
@@ -1,7 +1,7 @@
#include "kdualcolortest.h"
#include <kdualcolorbutton.h>
-#include <kapplication.h>
-#include <klocale.h>
+#include <tdeapplication.h>
+#include <tdelocale.h>
#include <tqlayout.h>
#include <tqpalette.h>
@@ -51,7 +51,7 @@ void KDualColorWidget::slotCurrentChanged(KDualColorButton::DualColor current)
int main(int argc, char **argv)
{
- KApplication *app = new KApplication(argc, argv, "KDualColorTest");
+ TDEApplication *app = new TDEApplication(argc, argv, "KDualColorTest");
KDualColorWidget w;
app->setMainWidget(&w);
w.show();
diff --git a/tdeui/tests/keditlistboxtest.cpp b/tdeui/tests/keditlistboxtest.cpp
index 90dbb74d0..5b4e45ddb 100644
--- a/tdeui/tests/keditlistboxtest.cpp
+++ b/tdeui/tests/keditlistboxtest.cpp
@@ -1,10 +1,10 @@
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <keditlistbox.h>
#include <kcombobox.h>
int main( int argc, char **argv )
{
- KApplication app( argc, argv, "keditlistboxtest" );
+ TDEApplication app( argc, argv, "keditlistboxtest" );
KEditListBox::CustomEditor editor( new KComboBox( true, 0L, "test" ) );
KEditListBox *box = new KEditListBox( TQString::fromLatin1("KEditListBox"),
diff --git a/tdeui/tests/kedittest.cpp b/tdeui/tests/kedittest.cpp
index 17a593e74..f806c3bdf 100644
--- a/tdeui/tests/kedittest.cpp
+++ b/tdeui/tests/kedittest.cpp
@@ -1,10 +1,10 @@
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <keditcl.h>
#include <tqpopupmenu.h>
int main( int argc, char **argv )
{
- KApplication app( argc, argv, "kedittest" );
+ TDEApplication app( argc, argv, "kedittest" );
KEdit *edit = new KEdit( 0L );
TQPopupMenu *pop = new TQPopupMenu( 0L );
pop->insertItem( "Popupmenu item" );
diff --git a/tdeui/tests/kgradienttest.cpp b/tdeui/tests/kgradienttest.cpp
index 6942ca55d..4ee8c0f93 100644
--- a/tdeui/tests/kgradienttest.cpp
+++ b/tdeui/tests/kgradienttest.cpp
@@ -1,5 +1,5 @@
#include "kgradienttest.h"
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <kpixmapeffect.h>
#include <tqpainter.h>
#include <tqdatetime.h>
@@ -98,7 +98,7 @@ void KGradientWidget::paintEvent(TQPaintEvent */*ev*/)
int main(int argc, char **argv)
{
- KApplication *app = new KApplication(argc, argv, "KGradientTest");
+ TDEApplication *app = new TDEApplication(argc, argv, "KGradientTest");
KGradientWidget w;
w.resize(250 * cols, 250 * rows);
app->setMainWidget(&w);
diff --git a/tdeui/tests/khashtest.cpp b/tdeui/tests/khashtest.cpp
index 2f00c9296..d392fcbc5 100644
--- a/tdeui/tests/khashtest.cpp
+++ b/tdeui/tests/khashtest.cpp
@@ -1,5 +1,5 @@
#include "khashtest.h"
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <kpixmapeffect.h>
#include <kimageeffect.h>
#include <tqpainter.h>
@@ -126,7 +126,7 @@ void KHashWidget::paintEvent(TQPaintEvent * /*ev*/)
int main(int argc, char **argv)
{
- KApplication *app = new KApplication(argc, argv, "KHashTest");
+ TDEApplication *app = new TDEApplication(argc, argv, "KHashTest");
KHashWidget w;
w.resize(250 * cols, 250 * rows);
app->setMainWidget(&w);
diff --git a/tdeui/tests/kinputdialogtest.cpp b/tdeui/tests/kinputdialogtest.cpp
index 66db4617a..b40b5c562 100644
--- a/tdeui/tests/kinputdialogtest.cpp
+++ b/tdeui/tests/kinputdialogtest.cpp
@@ -3,7 +3,7 @@
* License: GPL V2
*/
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <kinputdialog.h>
#include <kdebug.h>
@@ -12,7 +12,7 @@
int main( int argc, char *argv[] )
{
- KApplication app( argc, argv, "kinputdialogtest" );
+ TDEApplication app( argc, argv, "kinputdialogtest" );
bool ok;
TQString svalue;
diff --git a/tdeui/tests/kjanuswidgettest.cpp b/tdeui/tests/kjanuswidgettest.cpp
index 59db252e2..71e72fb13 100644
--- a/tdeui/tests/kjanuswidgettest.cpp
+++ b/tdeui/tests/kjanuswidgettest.cpp
@@ -1,4 +1,4 @@
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <kjanuswidget.h>
#include <tqstring.h>
@@ -7,7 +7,7 @@
int main(int argc, char** argv)
{
- KApplication app(argc, argv, "JanusWidgetTest");
+ TDEApplication app(argc, argv, "JanusWidgetTest");
// -----
KJanusWidget* janus = new KJanusWidget( 0, 0, KJanusWidget::IconList );
diff --git a/tdeui/tests/kledtest.cpp b/tdeui/tests/kledtest.cpp
index 54ae8b6e1..4ba158776 100644
--- a/tdeui/tests/kledtest.cpp
+++ b/tdeui/tests/kledtest.cpp
@@ -1,4 +1,4 @@
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <tqwidget.h>
#include <tqtimer.h>
#include <stdlib.h>
@@ -134,7 +134,7 @@ KLedTest::timeout()
int main( int argc, char **argv )
{
- KApplication a( argc, argv, "KLedTest" );
+ TDEApplication a( argc, argv, "KLedTest" );
KLedTest widget;
// -----
/*
diff --git a/tdeui/tests/klineeditdlgtest.cpp b/tdeui/tests/klineeditdlgtest.cpp
index 7db673bb1..ecc6ac984 100644
--- a/tdeui/tests/klineeditdlgtest.cpp
+++ b/tdeui/tests/klineeditdlgtest.cpp
@@ -1,4 +1,4 @@
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <klineeditdlg.h>
#include <tqstring.h>
@@ -6,7 +6,7 @@
int main(int argc, char** argv)
{
- KApplication app(argc, argv, "klineedittest");
+ TDEApplication app(argc, argv, "klineedittest");
KLineEditDlg dialog( "_text", "_value", 0L );
if(dialog.exec())
{
diff --git a/tdeui/tests/klineedittest.cpp b/tdeui/tests/klineedittest.cpp
index 3508982fa..20e9b6ca8 100644
--- a/tdeui/tests/klineedittest.cpp
+++ b/tdeui/tests/klineedittest.cpp
@@ -4,15 +4,15 @@
#include <tqhbox.h>
#include <tqtimer.h>
-#include <kaboutdata.h>
-#include <kcmdlineargs.h>
-#include <kapplication.h>
+#include <tdeaboutdata.h>
+#include <tdecmdlineargs.h>
+#include <tdeapplication.h>
#include <kdebug.h>
#include <kdialog.h>
-#include <klocale.h>
+#include <tdelocale.h>
#include <klineedit.h>
-#include <kglobalsettings.h>
-#include <kcompletionbox.h>
+#include <tdeglobalsettings.h>
+#include <tdecompletionbox.h>
#include "klineedittest.h"
@@ -118,11 +118,11 @@ void KLineEditTest::slotHide()
int main ( int argc, char **argv)
{
- KAboutData aboutData( "klineedittest", "klineedittest", "1.0" );
- KCmdLineArgs::init(argc, argv, &aboutData);
- KApplication::addCmdLineOptions();
+ TDEAboutData aboutData( "klineedittest", "klineedittest", "1.0" );
+ TDECmdLineArgs::init(argc, argv, &aboutData);
+ TDEApplication::addCmdLineOptions();
- KApplication a;
+ TDEApplication a;
KLineEditTest *t = new KLineEditTest();
//t->lineEdit()->setTrapReturnKey( true );
//t->lineEdit()->completionBox()->setTabHandling( false );
diff --git a/tdeui/tests/klistviewtest.cpp b/tdeui/tests/klistviewtest.cpp
deleted file mode 100644
index 6189c76e9..000000000
--- a/tdeui/tests/klistviewtest.cpp
+++ /dev/null
@@ -1,39 +0,0 @@
-#include <klistview.h>
-#include <kapplication.h>
-#include <kdialogbase.h>
-#include <tqvbox.h>
-
-
-int main( int argc, char **argv )
-{
- KApplication app( argc, argv, "klistviewtest" );
- KDialogBase dialog;
- KListView *view = new KListView( dialog.makeVBoxMainWidget() );
- view->setSelectionModeExt( KListView::FileManager );
- view->setDragEnabled( true );
- view->setItemsMovable( false );
- view->setAcceptDrops( true );
- view->addColumn("Column 1");
- view->addColumn("Column 2");
- view->addColumn("Column 3");
-
- new KListViewItem( view, "Item 1");
- new KListViewItem( view, "Item 1");
- new KListViewItem( view, "Item 1");
- new KListViewItem( view, "Item 1");
- new KListViewItem( view, "Item 1");
- new KListViewItem( view, "Item 1");
- new KListViewItem( view, "Item 1");
- new KListViewItem( view, "Item 1");
- new KListViewItem( view, "Item 1");
- new KListViewItem( view, "Item 2", "Some more", "Hi Mom :)" );
-
- view->restoreLayout( KGlobal::config(), "ListView" );
-
- new KListViewItem( view, "Item 3" );
-
- dialog.exec();
- view->saveLayout( KGlobal::config(), "ListView" );
-
- return 0;
-}
diff --git a/tdeui/tests/kmainwindowrestoretest.h b/tdeui/tests/kmainwindowrestoretest.h
deleted file mode 100644
index f29ae2fca..000000000
--- a/tdeui/tests/kmainwindowrestoretest.h
+++ /dev/null
@@ -1,48 +0,0 @@
-#ifndef _TDEUI_TESTS_KMAINWINDOWRESTORETEST_H_
-#define _TDEUI_TESTS_KMAINWINDOWRESTORETEST_H_
-
-#include <kmainwindow.h>
-
-class MainWin1 : public KMainWindow {
- Q_OBJECT
-public:
- MainWin1() : KMainWindow() {}
- virtual ~MainWin1() {}
-};
-
-class MainWin2 : public KMainWindow {
- Q_OBJECT
-public:
- MainWin2() : KMainWindow() {}
- virtual ~MainWin2() {}
-};
-
-class MainWin3 : public KMainWindow {
- Q_OBJECT
-public:
- MainWin3() : KMainWindow() {}
- virtual ~MainWin3() {}
-};
-
-class MainWin4 : public KMainWindow {
- Q_OBJECT
-public:
- MainWin4() : KMainWindow() {}
- virtual ~MainWin4() {}
-};
-
-class MainWin5 : public KMainWindow {
- Q_OBJECT
-public:
- MainWin5() : KMainWindow() {}
- virtual ~MainWin5() {}
-};
-
-class MainWin6 : public KMainWindow {
- Q_OBJECT
-public:
- MainWin6() : KMainWindow() {}
- virtual ~MainWin6() {}
-};
-
-#endif // _TDEUI_TESTS_KMAINWINDOWRESTORETEST_H_
diff --git a/tdeui/tests/kmessageboxtest.cpp b/tdeui/tests/kmessageboxtest.cpp
index 3603edf57..2a56a7ead 100644
--- a/tdeui/tests/kmessageboxtest.cpp
+++ b/tdeui/tests/kmessageboxtest.cpp
@@ -1,4 +1,4 @@
-#include "kmessagebox.h"
+#include "tdemessagebox.h"
#include <tqdialog.h>
#include <tqlayout.h>
@@ -8,9 +8,9 @@
#include <stdio.h>
#include <kstatusbar.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
-#include <kglobal.h>
+#include <tdeglobal.h>
class ExampleWidget : public QLabel
{
@@ -63,7 +63,7 @@ void showResult(int test, int i)
int main( int argc, char *argv[] )
{
int i, test;
- new KApplication( argc, argv, "MyApplication" );
+ new TDEApplication( argc, argv, "MyApplication" );
ExampleWidget *w = new ExampleWidget();
w->show();
diff --git a/tdeui/tests/knuminputtest.cpp b/tdeui/tests/knuminputtest.cpp
index fdf8697e9..9a333dfda 100644
--- a/tdeui/tests/knuminputtest.cpp
+++ b/tdeui/tests/knuminputtest.cpp
@@ -11,12 +11,12 @@
#include <tqlayout.h>
#include <tqvgroupbox.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <knuminput.h>
#include "knuminputtest.h"
-KApplication *a;
+TDEApplication *a;
#include <kdebug.h>
void TopLevel::slotPrint( int n ) {
@@ -132,7 +132,7 @@ TopLevel::TopLevel(TQWidget *parent, const char *name)
int main( int argc, char ** argv )
{
- a = new KApplication ( argc, argv, "KNuminputTest" );
+ a = new TDEApplication ( argc, argv, "KNuminputTest" );
TopLevel *toplevel = new TopLevel(0, "knuminputtest");
diff --git a/tdeui/tests/kpalettetest.cpp b/tdeui/tests/kpalettetest.cpp
index 32b91ff96..94036244e 100644
--- a/tdeui/tests/kpalettetest.cpp
+++ b/tdeui/tests/kpalettetest.cpp
@@ -1,5 +1,5 @@
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <tqwidget.h>
#include <tqtimer.h>
#include <stdlib.h>
@@ -12,7 +12,7 @@
int main( int argc, char **argv )
{
- KApplication a( argc, argv, "KPalettetest" );
+ TDEApplication a( argc, argv, "KPalettetest" );
TQStringList palettes = KPalette::getPaletteList();
for(TQStringList::ConstIterator it = palettes.begin();
diff --git a/tdeui/tests/kpanelmenutest.cpp b/tdeui/tests/kpanelmenutest.cpp
index 678a1eeb6..a14cb3366 100644
--- a/tdeui/tests/kpanelmenutest.cpp
+++ b/tdeui/tests/kpanelmenutest.cpp
@@ -1,5 +1,5 @@
#include "kpanelmenutest.h"
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <kstandarddirs.h>
#include <dcopclient.h>
@@ -57,7 +57,7 @@ void TestWidget::slotSubMenuCalled(int id)
int main(int argc, char **argv)
{
- KApplication *app = new KApplication(argc, argv, "menutest");
+ TDEApplication *app = new TDEApplication(argc, argv, "menutest");
TestWidget w;
app->setMainWidget(&w);
diff --git a/tdeui/tests/kpixmapregionselectordialogtest.cpp b/tdeui/tests/kpixmapregionselectordialogtest.cpp
index c698c66f2..28a51a3f7 100644
--- a/tdeui/tests/kpixmapregionselectordialogtest.cpp
+++ b/tdeui/tests/kpixmapregionselectordialogtest.cpp
@@ -1,23 +1,23 @@
#include "kpixmapregionselectordialog.h"
#include <tqpixmap.h>
#include <tqimage.h>
-#include <kapplication.h>
-#include <kcmdlineargs.h>
+#include <tdeapplication.h>
+#include <tdecmdlineargs.h>
#include <iostream>
-static const KCmdLineOptions options[] =
+static const TDECmdLineOptions options[] =
{
{ "+file", "The image file to open", 0 },
- KCmdLineLastOption
+ TDECmdLineLastOption
};
int main(int argc, char**argv)
{
- KCmdLineArgs::init(argc, argv, "test", "test" ,"test" ,"1.0");
- KCmdLineArgs::addCmdLineOptions( options );
- KApplication app("test");
+ TDECmdLineArgs::init(argc, argv, "test", "test" ,"test" ,"1.0");
+ TDECmdLineArgs::addCmdLineOptions( options );
+ TDEApplication app("test");
- KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+ TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
if (args->count()!=1)
{
std::cout << "Usage: kpixmapregionselectordialogtest <imageFile>" << std::endl;
diff --git a/tdeui/tests/kprogresstest.cpp b/tdeui/tests/kprogresstest.cpp
index 7b7024135..6106a236b 100644
--- a/tdeui/tests/kprogresstest.cpp
+++ b/tdeui/tests/kprogresstest.cpp
@@ -1,4 +1,4 @@
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <tqwidget.h>
#include "kprogress.h"
@@ -46,7 +46,7 @@ void MyWidget::timerEvent(TQTimerEvent *)
int main(int argc, char *argv[])
{
- KApplication app(argc, argv, "KProgressTest");
+ TDEApplication app(argc, argv, "KProgressTest");
MyWidget w;
app.setMainWidget(&w);
diff --git a/tdeui/tests/krulertest.cpp b/tdeui/tests/krulertest.cpp
index 2f16605d9..628c5096e 100644
--- a/tdeui/tests/krulertest.cpp
+++ b/tdeui/tests/krulertest.cpp
@@ -51,7 +51,7 @@ MouseWidget::resizeEvent( TQResizeEvent *r )
KRulerTest::KRulerTest( const char *name )
- : KMainWindow(0, name)
+ : TDEMainWindow(0, name)
{
mainframe = new TQFrame(this);
@@ -358,10 +358,10 @@ KRulerTest::slotSetYTrans(double d)
/* --- MAIN -----------------------*/
int main(int argc, char **argv)
{
- KApplication *testapp;
+ TDEApplication *testapp;
KRulerTest *window;
- testapp = new KApplication(argc, argv,"krulertest");
+ testapp = new TDEApplication(argc, argv,"krulertest");
testapp->setFont(TQFont("Helvetica",12),true);
window = new KRulerTest("main");
diff --git a/tdeui/tests/krulertest.h b/tdeui/tests/krulertest.h
index d180e93a0..0242fb5d7 100644
--- a/tdeui/tests/krulertest.h
+++ b/tdeui/tests/krulertest.h
@@ -3,8 +3,8 @@
#ifndef krulertest_h
#define krulertest_h
-#include <kapplication.h>
-#include <kmainwindow.h>
+#include <tdeapplication.h>
+#include <tdemainwindow.h>
#include <tqwidget.h>
#include <tqcheckbox.h>
#include <tqradiobutton.h>
@@ -42,7 +42,7 @@ private:
};
-class KRulerTest : public KMainWindow
+class KRulerTest : public TDEMainWindow
{
Q_OBJECT
public:
diff --git a/tdeui/tests/kseparatortest.cpp b/tdeui/tests/kseparatortest.cpp
index 17e965ca8..a791fa930 100644
--- a/tdeui/tests/kseparatortest.cpp
+++ b/tdeui/tests/kseparatortest.cpp
@@ -18,7 +18,7 @@
*/
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <tqlayout.h>
#include <tqwidget.h>
diff --git a/tdeui/tests/ksqueezedtextlabeltest.cpp b/tdeui/tests/ksqueezedtextlabeltest.cpp
index 62f3c1a76..7c3fd413c 100644
--- a/tdeui/tests/ksqueezedtextlabeltest.cpp
+++ b/tdeui/tests/ksqueezedtextlabeltest.cpp
@@ -1,9 +1,9 @@
#include "ksqueezedtextlabel.h"
-#include <kapplication.h>
+#include <tdeapplication.h>
int main( int argc, char **argv )
{
- KApplication app( argc, argv, "KSqueezedTextLabelTest" );
+ TDEApplication app( argc, argv, "KSqueezedTextLabelTest" );
KSqueezedTextLabel l( "This is a rather long string", 0);
app.setMainWidget( &l );
diff --git a/tdeui/tests/kstatusbartest.cpp b/tdeui/tests/kstatusbartest.cpp
index 669044c55..0a8c6d10c 100644
--- a/tdeui/tests/kstatusbartest.cpp
+++ b/tdeui/tests/kstatusbartest.cpp
@@ -10,19 +10,19 @@
#include <stdlib.h>
#include "kstatusbar.h"
-#include <kapplication.h>
-#include <kmainwindow.h>
-#include <kmenubar.h>
+#include <tdeapplication.h>
+#include <tdemainwindow.h>
+#include <tdemenubar.h>
#include "kstatusbartest.h"
testWindow::testWindow (TQWidget *, const char *name)
- : KMainWindow (0, name)
+ : TDEMainWindow (0, name)
{
// Setup Menus
menuBar = new KMenuBar (this);
fileMenu = new TQPopupMenu;
menuBar->insertItem ("&File", fileMenu);
- fileMenu->insertItem ("&Exit", KApplication::kApplication(),
+ fileMenu->insertItem ("&Exit", TDEApplication::kApplication(),
TQT_SLOT( quit() ), ALT + Key_Q );
statusbar = new KStatusBar (this);
statusbar->insertItem("Zoom: XXXX", 0);
@@ -41,7 +41,7 @@ testWindow::testWindow (TQWidget *, const char *name)
setCentralWidget(widget);
- setCaption( KApplication::kApplication()->caption() );
+ setCaption( TDEApplication::kApplication()->caption() );
smenu = new TQPopupMenu;
@@ -104,7 +104,7 @@ testWindow::~testWindow ()
int main( int argc, char *argv[] )
{
- KApplication *myApp = new KApplication( argc, argv, "KStatusBarTest" );
+ TDEApplication *myApp = new TDEApplication( argc, argv, "KStatusBarTest" );
testWindow *test = new testWindow;
myApp->setMainWidget(test);
diff --git a/tdeui/tests/kstatusbartest.h b/tdeui/tests/kstatusbartest.h
index 37f500334..712f24352 100644
--- a/tdeui/tests/kstatusbartest.h
+++ b/tdeui/tests/kstatusbartest.h
@@ -1,14 +1,14 @@
#ifndef test_kstatusbar_h
#define test_kstatusbar_h
-#include <kmenubar.h>
+#include <tdemenubar.h>
#include <tqpopupmenu.h>
#include <kstatusbar.h>
-#include <kmainwindow.h>
+#include <tdemainwindow.h>
class TQMultiLineEdit;
-class testWindow : public KMainWindow
+class testWindow : public TDEMainWindow
{
Q_OBJECT
diff --git a/tdeui/tests/ksystemtraytest.cpp b/tdeui/tests/ksystemtraytest.cpp
index dcee78346..27a6629d9 100644
--- a/tdeui/tests/ksystemtraytest.cpp
+++ b/tdeui/tests/ksystemtraytest.cpp
@@ -1,9 +1,9 @@
#include <ksystemtray.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
int main(int argc, char **argv)
{
- KApplication app( argc, argv, "ksystemtraytest" );
+ TDEApplication app( argc, argv, "ksystemtraytest" );
TQLabel *l = new TQLabel("System Tray Main Window", 0L);
KSystemTray *tray = new KSystemTray( l );
tray->setText("Test");
diff --git a/tdeui/tests/ktabctltest.cpp b/tdeui/tests/ktabctltest.cpp
index 33e7fc5b7..05fe2aeb3 100644
--- a/tdeui/tests/ktabctltest.cpp
+++ b/tdeui/tests/ktabctltest.cpp
@@ -2,7 +2,7 @@
*
*/
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <tqpushbutton.h>
#include <tqlabel.h>
#include <tqobject.h>
@@ -30,7 +30,7 @@
TQFont default_font("Helvetica", 12);
-KApplication *a;
+TDEApplication *a;
TopLevel::TopLevel(TQWidget *parent, const char *name)
: TQWidget(parent, name)
@@ -90,7 +90,7 @@ void TopLevel::okPressed()
int main( int argc, char ** argv )
{
- a = new KApplication ( argc, argv, "KTabCtlTest" );
+ a = new TDEApplication ( argc, argv, "KTabCtlTest" );
a->setFont(default_font);
diff --git a/tdeui/tests/ktabwidgettest.cpp b/tdeui/tests/ktabwidgettest.cpp
index 32ed5c89f..64d2795fc 100644
--- a/tdeui/tests/ktabwidgettest.cpp
+++ b/tdeui/tests/ktabwidgettest.cpp
@@ -2,8 +2,8 @@
#include <tqlayout.h>
#include <tqdragobject.h>
-#include <kapplication.h>
-#include <kcmdlineargs.h>
+#include <tdeapplication.h>
+#include <tdecmdlineargs.h>
#include <kinputdialog.h>
#include <kdebug.h>
@@ -354,8 +354,8 @@ void Test::toggleLabels(bool state)
int main(int argc, char** argv )
{
- KCmdLineArgs::init(argc, argv, "ktabwidgettest", "ktabwidget test app", "1.0");
- KApplication app(argc, argv);
+ TDECmdLineArgs::init(argc, argv, "ktabwidgettest", "ktabwidget test app", "1.0");
+ TDEApplication app(argc, argv);
Test *t = new Test();
app.setMainWidget( t );
diff --git a/tdeui/tests/ktextedittest.cpp b/tdeui/tests/ktextedittest.cpp
index d43f77260..6570bf26d 100644
--- a/tdeui/tests/ktextedittest.cpp
+++ b/tdeui/tests/ktextedittest.cpp
@@ -17,14 +17,14 @@
Boston, MA 02110-1301, USA.
*/
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <ktextedit.h>
#include <tqfile.h>
int main( int argc, char **argv )
{
- KApplication app( argc, argv, "ktextedittest" );
+ TDEApplication app( argc, argv, "ktextedittest" );
KTextEdit *edit = new KTextEdit();
edit->setReadOnly( true );
edit->setCheckSpellingEnabled( true );
diff --git a/tdeui/tests/ktimewidgettest.cpp b/tdeui/tests/ktimewidgettest.cpp
index 324accc7d..731dc3219 100644
--- a/tdeui/tests/ktimewidgettest.cpp
+++ b/tdeui/tests/ktimewidgettest.cpp
@@ -1,11 +1,11 @@
#include "ktimewidget.h"
-#include <kapplication.h>
-#include <klocale.h>
+#include <tdeapplication.h>
+#include <tdelocale.h>
int main(int argc, char** argv)
{
- KLocale::setMainCatalogue("tdelibs");
- KApplication app(argc, argv, "KTimeWidgettest");
+ TDELocale::setMainCatalogue("tdelibs");
+ TDEApplication app(argc, argv, "KTimeWidgettest");
KTimeWidget timeWidget;
app.setMainWidget(&timeWidget);
timeWidget.show();
diff --git a/tdeui/tests/kunbalancedgrdtest.cpp b/tdeui/tests/kunbalancedgrdtest.cpp
index 7f5b2cc78..40904000b 100644
--- a/tdeui/tests/kunbalancedgrdtest.cpp
+++ b/tdeui/tests/kunbalancedgrdtest.cpp
@@ -1,5 +1,5 @@
#include "kunbalancedgrdtest.h"
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <kpixmapeffect.h>
#include <tqpainter.h>
#include <tqstring.h>
@@ -166,7 +166,7 @@ void myTopWidget::rebalance()
int main(int argc, char **argv)
{
- KApplication *app = new KApplication(argc, argv, "KUnbalancedGradientTest");
+ TDEApplication *app = new TDEApplication(argc, argv, "KUnbalancedGradientTest");
myTopWidget w;
app->setMainWidget(&w);
w.show();
diff --git a/tdeui/tests/kwizardtest.cpp b/tdeui/tests/kwizardtest.cpp
index 91974263e..0635188d0 100644
--- a/tdeui/tests/kwizardtest.cpp
+++ b/tdeui/tests/kwizardtest.cpp
@@ -20,12 +20,12 @@
#include <tqlabel.h>
#include <tqlayout.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <kwizard.h>
int main(int argc, char **argv)
{
- KApplication a(argc,argv,"kwizardtest");
+ TDEApplication a(argc,argv,"kwizardtest");
KWizard *wiz = new KWizard(0, "kwizardtest", false);
TQObject::connect((TQObject*) wiz->cancelButton(), TQT_SIGNAL(clicked()),
&a, TQT_SLOT(quit()));
diff --git a/tdeui/tests/kwordwraptest.cpp b/tdeui/tests/kwordwraptest.cpp
index ad60bd897..690fbf157 100644
--- a/tdeui/tests/kwordwraptest.cpp
+++ b/tdeui/tests/kwordwraptest.cpp
@@ -16,14 +16,14 @@
* Boston, MA 02110-1301, USA.
*/
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <kdebug.h>
#include <tqwidget.h>
#include "kwordwrap.h"
int main(int argc, char *argv[])
{
- KApplication app(argc, argv, "KWordWrapTest");
+ TDEApplication app(argc, argv, "KWordWrapTest");
TQFont font( "helvetica", 12 ); // let's hope we all have the same...
TQFontMetrics fm( font );
diff --git a/tdeui/tests/kxmlguitest.cpp b/tdeui/tests/kxmlguitest.cpp
index a903aeb3f..1a79526aa 100644
--- a/tdeui/tests/kxmlguitest.cpp
+++ b/tdeui/tests/kxmlguitest.cpp
@@ -1,10 +1,10 @@
#include "kxmlguitest.h"
-#include <kapplication.h>
-#include <kmainwindow.h>
+#include <tdeapplication.h>
+#include <tdemainwindow.h>
#include <kxmlguifactory.h>
#include <kxmlguiclient.h>
#include <kxmlguibuilder.h>
-#include <kaction.h>
+#include <tdeaction.h>
#include <kdebug.h>
#include <kstdaction.h>
#include <kstandarddirs.h>
@@ -18,13 +18,13 @@ void Client::slotSec()
int main( int argc, char **argv )
{
- KApplication app( argc, argv, "kxmlguitest" );
+ TDEApplication app( argc, argv, "kxmlguitest" );
// KXMLGUIClient looks in the "data" resource for the .rc files
// Let's add $PWD (ideally $srcdir instead...) to it
- KGlobal::dirs()->addResourceDir( "data", TQDir::currentDirPath() );
+ TDEGlobal::dirs()->addResourceDir( "data", TQDir::currentDirPath() );
- KMainWindow *mainwindow = new KMainWindow;
+ TDEMainWindow *mainwindow = new TDEMainWindow;
TQLineEdit* line = new TQLineEdit( mainwindow );
mainwindow->setCentralWidget( line );
@@ -36,10 +36,10 @@ int main( int argc, char **argv )
KXMLGUIFactory *factory = new KXMLGUIFactory( builder );
Client *shell = new Client;
- shell->setInstance( new KInstance( "konqueror" ) );
+ shell->setInstance( new TDEInstance( "konqueror" ) );
shell->instance()->dirs()->addResourceDir( "data", TQDir::currentDirPath() );
- (void)new KAction( "Split", "view_left_right", 0, 0, 0, shell->actionCollection(), "splitviewh" );
+ (void)new TDEAction( "Split", "view_left_right", 0, 0, 0, shell->actionCollection(), "splitviewh" );
shell->setXMLFile( "./kxmlguitest_shell.rc" );
@@ -47,8 +47,8 @@ int main( int argc, char **argv )
Client *part = new Client;
- (void)new KAction( "decfont", "viewmag-", 0, 0, 0, part->actionCollection(), "decFontSizes" );
- (void)new KAction( "sec", "unlock", Qt::ALT + Qt::Key_1, part, TQT_SLOT( slotSec() ), part->actionCollection(), "security" );
+ (void)new TDEAction( "decfont", "viewmag-", 0, 0, 0, part->actionCollection(), "decFontSizes" );
+ (void)new TDEAction( "sec", "unlock", Qt::ALT + Qt::Key_1, part, TQT_SLOT( slotSec() ), part->actionCollection(), "security" );
part->setXMLFile( "./kxmlguitest_part.rc" );
diff --git a/tdeui/tests/kxmlguitest.h b/tdeui/tests/kxmlguitest.h
index 1adb1a14b..bc88711f7 100644
--- a/tdeui/tests/kxmlguitest.h
+++ b/tdeui/tests/kxmlguitest.h
@@ -11,7 +11,7 @@ public:
Client() {}
void setXMLFile( const TQString &f, bool merge = true ) { KXMLGUIClient::setXMLFile( f, merge ); }
- void setInstance( KInstance *inst ) { KXMLGUIClient::setInstance( inst ); }
+ void setInstance( TDEInstance *inst ) { KXMLGUIClient::setInstance( inst ); }
public slots:
void slotSec();
diff --git a/tdeui/tests/kxmlguitest_part.rc b/tdeui/tests/kxmlguitest_part.rc
index 84f5e4f57..b6454cf30 100644
--- a/tdeui/tests/kxmlguitest_part.rc
+++ b/tdeui/tests/kxmlguitest_part.rc
@@ -1,5 +1,5 @@
<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
-<kpartgui name="khtmlpart" version="7">
+<kpartgui name="tdehtmlpart" version="7">
<ToolBar name="mainToolBar"><text>Main Toolbar</text>
<Action name="decFontSizes" />
<Separator />
diff --git a/tdeui/tests/kaccelgentest.cpp b/tdeui/tests/tdeaccelgentest.cpp
index f5f95ac57..bd456aefd 100644
--- a/tdeui/tests/kaccelgentest.cpp
+++ b/tdeui/tests/tdeaccelgentest.cpp
@@ -1,4 +1,4 @@
-#include "kaccelgen.h"
+#include "tdeaccelgen.h"
#include <tqstringlist.h>
@@ -30,7 +30,7 @@ int main()
<< "&yoyo && dyne";
TQStringList output;
- KAccelGen::generate( input, output );
+ TDEAccelGen::generate( input, output );
check( "TQStringList value generation", expected, output );
TQMap<TQString,TQString> map;
@@ -39,13 +39,13 @@ int main()
}
input.sort();
expected.clear();
- KAccelGen::generate( input, expected );
+ TDEAccelGen::generate( input, expected );
output.clear();
- KAccelGen::generateFromValues( map, output );
+ TDEAccelGen::generateFromValues( map, output );
check( "map value generation", expected, output );
output.clear();
- KAccelGen::generateFromKeys( map, output );
+ TDEAccelGen::generateFromKeys( map, output );
check( "map key generation", expected, output );
}
diff --git a/tdeui/tests/tdeactiontest.cpp b/tdeui/tests/tdeactiontest.cpp
new file mode 100644
index 000000000..dcec16189
--- /dev/null
+++ b/tdeui/tests/tdeactiontest.cpp
@@ -0,0 +1,38 @@
+
+#include <tqguardedptr.h>
+
+#include <tdeapplication.h>
+#include <tdeaction.h>
+
+#include <assert.h>
+
+int main( int argc, char **argv )
+{
+ TDEApplication app( argc, argv, "tdeactiontest" );
+
+ TDEActionCollection coll( static_cast<TQObject *>( 0 ) );
+
+ TQGuardedPtr<TDEAction> action1 = new TDERadioAction("test",0, &coll);
+ TQGuardedPtr<TDEAction> action2 = new TDERadioAction("test",0, &coll);
+ TQGuardedPtr<TDEAction> action3 = new TDERadioAction("test",0, &coll);
+ TQGuardedPtr<TDEAction> action4 = new TDERadioAction("test",0, &coll);
+ TQGuardedPtr<TDEAction> action5 = new TDERadioAction("test",0, &coll);
+ TQGuardedPtr<TDEAction> action6 = new TDERadioAction("test",0, &coll);
+ TQGuardedPtr<TDEAction> action7 = new TDERadioAction("test",0, &coll);
+
+ coll.clear();
+ assert( coll.isEmpty() );
+
+ assert( action1.isNull() );
+ assert( action2.isNull() );
+ assert( action3.isNull() );
+ assert( action4.isNull() );
+ assert( action5.isNull() );
+ assert( action6.isNull() );
+ assert( action7.isNull() );
+
+ return 0;
+}
+
+/* vim: et sw=4 ts=4
+ */
diff --git a/tdeui/tests/kfontdialogtest.cpp b/tdeui/tests/tdefontdialogtest.cpp
index 205fd48f7..ff7ac2840 100644
--- a/tdeui/tests/kfontdialogtest.cpp
+++ b/tdeui/tests/tdefontdialogtest.cpp
@@ -24,26 +24,26 @@
*/
-#include <kapplication.h>
-#include "kfontdialog.h"
-#include <kconfig.h>
+#include <tdeapplication.h>
+#include "tdefontdialog.h"
+#include <tdeconfig.h>
int main( int argc, char **argv )
{
- KApplication app( argc, argv, "KFontDialogTest" );
+ TDEApplication app( argc, argv, "TDEFontDialogTest" );
- KConfig aConfig;
- aConfig.setGroup( "KFontDialog-test" );
+ TDEConfig aConfig;
+ aConfig.setGroup( "TDEFontDialog-test" );
app.setFont(TQFont("Helvetica",12));
// TQFont font = TQFont("Times",18,TQFont::Bold);
TQFont font = aConfig.readFontEntry( "Chosen" );
- int nRet = KFontDialog::getFont(font);
+ int nRet = TDEFontDialog::getFont(font);
int flags;
- nRet = KFontDialog::getFontDiff(font, flags);
+ nRet = TDEFontDialog::getFontDiff(font, flags);
aConfig.writeEntry( "Chosen", font, true );
aConfig.sync();
diff --git a/tdeui/tests/tdelistviewtest.cpp b/tdeui/tests/tdelistviewtest.cpp
new file mode 100644
index 000000000..c2a0e78cf
--- /dev/null
+++ b/tdeui/tests/tdelistviewtest.cpp
@@ -0,0 +1,39 @@
+#include <tdelistview.h>
+#include <tdeapplication.h>
+#include <kdialogbase.h>
+#include <tqvbox.h>
+
+
+int main( int argc, char **argv )
+{
+ TDEApplication app( argc, argv, "tdelistviewtest" );
+ KDialogBase dialog;
+ TDEListView *view = new TDEListView( dialog.makeVBoxMainWidget() );
+ view->setSelectionModeExt( TDEListView::FileManager );
+ view->setDragEnabled( true );
+ view->setItemsMovable( false );
+ view->setAcceptDrops( true );
+ view->addColumn("Column 1");
+ view->addColumn("Column 2");
+ view->addColumn("Column 3");
+
+ new TDEListViewItem( view, "Item 1");
+ new TDEListViewItem( view, "Item 1");
+ new TDEListViewItem( view, "Item 1");
+ new TDEListViewItem( view, "Item 1");
+ new TDEListViewItem( view, "Item 1");
+ new TDEListViewItem( view, "Item 1");
+ new TDEListViewItem( view, "Item 1");
+ new TDEListViewItem( view, "Item 1");
+ new TDEListViewItem( view, "Item 1");
+ new TDEListViewItem( view, "Item 2", "Some more", "Hi Mom :)" );
+
+ view->restoreLayout( TDEGlobal::config(), "ListView" );
+
+ new TDEListViewItem( view, "Item 3" );
+
+ dialog.exec();
+ view->saveLayout( TDEGlobal::config(), "ListView" );
+
+ return 0;
+}
diff --git a/tdeui/tests/kmainwindowrestoretest.cpp b/tdeui/tests/tdemainwindowrestoretest.cpp
index 7415085ac..559348ec0 100644
--- a/tdeui/tests/kmainwindowrestoretest.cpp
+++ b/tdeui/tests/tdemainwindowrestoretest.cpp
@@ -1,7 +1,7 @@
-#include "kmainwindowrestoretest.h"
+#include "tdemainwindowrestoretest.h"
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <tqlabel.h>
@@ -14,7 +14,7 @@
int main( int argc, char * argv[] ) {
- KApplication app( argc, argv, "kmainwindowrestoretest" );
+ TDEApplication app( argc, argv, "tdemainwindowrestoretest" );
if ( kapp->isRestored() ) {
kRestoreMainWindows< MainWin1, MainWin2, MainWin3 >();
@@ -38,4 +38,4 @@ int main( int argc, char * argv[] ) {
return app.exec();
}
-#include "kmainwindowrestoretest.moc"
+#include "tdemainwindowrestoretest.moc"
diff --git a/tdeui/tests/tdemainwindowrestoretest.h b/tdeui/tests/tdemainwindowrestoretest.h
new file mode 100644
index 000000000..7d02e4aca
--- /dev/null
+++ b/tdeui/tests/tdemainwindowrestoretest.h
@@ -0,0 +1,48 @@
+#ifndef _TDEUI_TESTS_KMAINWINDOWRESTORETEST_H_
+#define _TDEUI_TESTS_KMAINWINDOWRESTORETEST_H_
+
+#include <tdemainwindow.h>
+
+class MainWin1 : public TDEMainWindow {
+ Q_OBJECT
+public:
+ MainWin1() : TDEMainWindow() {}
+ virtual ~MainWin1() {}
+};
+
+class MainWin2 : public TDEMainWindow {
+ Q_OBJECT
+public:
+ MainWin2() : TDEMainWindow() {}
+ virtual ~MainWin2() {}
+};
+
+class MainWin3 : public TDEMainWindow {
+ Q_OBJECT
+public:
+ MainWin3() : TDEMainWindow() {}
+ virtual ~MainWin3() {}
+};
+
+class MainWin4 : public TDEMainWindow {
+ Q_OBJECT
+public:
+ MainWin4() : TDEMainWindow() {}
+ virtual ~MainWin4() {}
+};
+
+class MainWin5 : public TDEMainWindow {
+ Q_OBJECT
+public:
+ MainWin5() : TDEMainWindow() {}
+ virtual ~MainWin5() {}
+};
+
+class MainWin6 : public TDEMainWindow {
+ Q_OBJECT
+public:
+ MainWin6() : TDEMainWindow() {}
+ virtual ~MainWin6() {}
+};
+
+#endif // _TDEUI_TESTS_KMAINWINDOWRESTORETEST_H_
diff --git a/tdeui/tests/kmainwindowtest.cpp b/tdeui/tests/tdemainwindowtest.cpp
index 5b7afd36f..b19818d4c 100644
--- a/tdeui/tests/kmainwindowtest.cpp
+++ b/tdeui/tests/tdemainwindowtest.cpp
@@ -1,11 +1,11 @@
#include <tqtimer.h>
#include <tqlabel.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <kstatusbar.h>
-#include <kmenubar.h>
+#include <tdemenubar.h>
-#include "kmainwindowtest.h"
+#include "tdemainwindowtest.h"
MainWindow::MainWindow()
{
@@ -24,7 +24,7 @@ void MainWindow::showMessage()
int main( int argc, char **argv )
{
- KApplication app( argc, argv, "kmainwindowtest" );
+ TDEApplication app( argc, argv, "tdemainwindowtest" );
MainWindow* mw = new MainWindow; // deletes itself when closed
mw->show();
@@ -32,7 +32,7 @@ int main( int argc, char **argv )
return app.exec();
}
-#include "kmainwindowtest.moc"
+#include "tdemainwindowtest.moc"
/* vim: et sw=4 ts=4
*/
diff --git a/tdeui/tests/kmainwindowtest.h b/tdeui/tests/tdemainwindowtest.h
index 4fb426ac5..b7c5d9e3c 100644
--- a/tdeui/tests/kmainwindowtest.h
+++ b/tdeui/tests/tdemainwindowtest.h
@@ -1,9 +1,9 @@
#ifndef KMAINWINDOWTEST_H
#define KMAINWINDOWTEST_H
-#include <kmainwindow.h>
+#include <tdemainwindow.h>
-class MainWindow : public KMainWindow
+class MainWindow : public TDEMainWindow
{
Q_OBJECT
public:
diff --git a/tdeui/tests/kpopuptest.cpp b/tdeui/tests/tdepopuptest.cpp
index 3db71106b..f9a97bad4 100644
--- a/tdeui/tests/kpopuptest.cpp
+++ b/tdeui/tests/tdepopuptest.cpp
@@ -1,11 +1,11 @@
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <tqwidget.h>
#include <tqcursor.h>
-#include "kpopupmenu.h"
+#include "tdepopupmenu.h"
class DemoWidget : public TQWidget {
private:
- KPopupMenu *menu;
+ TDEPopupMenu *menu;
void mousePressEvent(TQMouseEvent *)
{
@@ -20,7 +20,7 @@ void paintEvent(TQPaintEvent *)
public:
DemoWidget() : TQWidget()
{
- menu = new KPopupMenu("Popup Menu:");
+ menu = new TDEPopupMenu("Popup Menu:");
menu->insertItem("Item1");
menu->insertItem("Item2");
menu->insertSeparator();
@@ -30,7 +30,7 @@ public:
int main(int argc, char **argv)
{
- KApplication app(argc, argv, "kpopupmenutest");
+ TDEApplication app(argc, argv, "tdepopupmenutest");
DemoWidget w;
app.setMainWidget(&w);
w.setFont(TQFont("helvetica", 12, TQFont::Bold), true);
diff --git a/tdeui/tests/kspelltest.cpp b/tdeui/tests/tdespelltest.cpp
index 9180ed376..5ec103b99 100644
--- a/tdeui/tests/kspelltest.cpp
+++ b/tdeui/tests/tdespelltest.cpp
@@ -16,8 +16,8 @@
Boston, MA 02110-1301, USA.
*/
-#include "kspell.h"
-#include <kapplication.h>
+#include "tdespell.h"
+#include <tdeapplication.h>
#include <kdebug.h>
#include <tqstring.h>
@@ -26,7 +26,7 @@
int main(int argc, char **argv)
{
- KApplication *app = new KApplication(argc, argv, "KSpellTest");
+ TDEApplication *app = new TDEApplication(argc, argv, "KSpellTest");
// test ASCII
//TQString text( "I have noo idee of how to wride englisch or englisch" );
diff --git a/tdeui/tests/ktoolbarlabelactiontest.cpp b/tdeui/tests/tdetoolbarlabelactiontest.cpp
index 020834605..b919c2725 100644
--- a/tdeui/tests/ktoolbarlabelactiontest.cpp
+++ b/tdeui/tests/tdetoolbarlabelactiontest.cpp
@@ -18,19 +18,19 @@
#include <tqguardedptr.h>
-#include <kapplication.h>
-#include <kmainwindow.h>
+#include <tdeapplication.h>
+#include <tdemainwindow.h>
#include <klineedit.h>
-#include <klistview.h>
+#include <tdelistview.h>
#include <kstandarddirs.h>
-#include <ktoolbarlabelaction.h>
+#include <tdetoolbarlabelaction.h>
#include <ksqueezedtextlabel.h>
#include <kdebug.h>
#include <tqvbox.h>
#include <assert.h>
-class MainWindow : public KMainWindow
+class MainWindow : public TDEMainWindow
{
public:
MainWindow()
@@ -47,7 +47,7 @@ public:
// first constructor
- KToolBarLabelAction* label1 = new KToolBarLabelAction("&Label 1", 0,
+ TDEToolBarLabelAction* label1 = new TDEToolBarLabelAction("&Label 1", 0,
0, 0,
actionCollection(),
"label1");
@@ -55,8 +55,8 @@ public:
KLineEdit* lineEdit = new KLineEdit(this);
new KWidgetAction(lineEdit, "Line Edit", 0, this, 0,
actionCollection(), "lineEdit");
- KToolBarLabelAction* label2 =
- new KToolBarLabelAction(lineEdit, "L&abel 2", 0, 0, 0,
+ TDEToolBarLabelAction* label2 =
+ new TDEToolBarLabelAction(lineEdit, "L&abel 2", 0, 0, 0,
actionCollection(),
"label2");
@@ -69,7 +69,7 @@ public:
("&Really long, long, long and boring text goes here", this,
"kde toolbar widget");
- KToolBarLabelAction* label3 = new KToolBarLabelAction(customLabel, 0, 0, 0,
+ TDEToolBarLabelAction* label3 = new TDEToolBarLabelAction(customLabel, 0, 0, 0,
actionCollection(),
"label3");
@@ -78,15 +78,15 @@ public:
// customLabel->setText("&test me again some time soon");
- createGUI("ktoolbarlabelactiontestui.rc");
+ createGUI("tdetoolbarlabelactiontestui.rc");
}
};
int main( int argc, char **argv )
{
- KApplication app( argc, argv, "ktoolbarlabelactiontest" );
+ TDEApplication app( argc, argv, "tdetoolbarlabelactiontest" );
- KGlobal::instance()->dirs()->addResourceDir("data", ".");
+ TDEGlobal::instance()->dirs()->addResourceDir("data", ".");
MainWindow* mw = new MainWindow;
app.setMainWidget(mw);
diff --git a/tdeui/tests/ktoolbarlabelactiontestui.rc b/tdeui/tests/tdetoolbarlabelactiontestui.rc
index 75d02e54e..0a0e03091 100644
--- a/tdeui/tests/ktoolbarlabelactiontestui.rc
+++ b/tdeui/tests/tdetoolbarlabelactiontestui.rc
@@ -1,5 +1,5 @@
<!DOCTYPE kpartgui>
-<kpartgui name="ktoolbarlabelactiontest" version="0.1">
+<kpartgui name="tdetoolbarlabelactiontest" version="0.1">
<ToolBar>
<Action name="label1"/>
<Action name="label2"/>
diff --git a/tdeui/tests/twindowtest.h b/tdeui/tests/twindowtest.h
index 14e2a6da8..d1d9d460e 100644
--- a/tdeui/tests/twindowtest.h
+++ b/tdeui/tests/twindowtest.h
@@ -4,16 +4,16 @@
#include <tqpopupmenu.h>
#include <tqtimer.h>
#include <tqprogressbar.h>
-#include <kmenubar.h>
+#include <tdemenubar.h>
#include <kstatusbar.h>
-#include <ktoolbar.h>
-#include <kmainwindow.h>
+#include <tdetoolbar.h>
+#include <tdemainwindow.h>
class TQMultiLineEdit;
-class KToolBarRadioGroup;
+class TDEToolBarRadioGroup;
class KHelpMenu;
-class testWindow : public KMainWindow
+class testWindow : public TDEMainWindow
{
Q_OBJECT
@@ -56,8 +56,8 @@ protected:
TQPopupMenu *toolBarMenu;
KStatusBar *statusBar;
KHelpMenu *helpMenu;
- KToolBar *tb;
- KToolBar *tb1;
+ TDEToolBar *tb;
+ TDEToolBar *tb1;
bool lineL;
bool exitB;
bool greenF;
@@ -65,7 +65,7 @@ protected:
TQMultiLineEdit *widget;
TQTimer *timer;
TQProgressBar *pr;
- KToolBarRadioGroup *rg;
+ TDEToolBarRadioGroup *rg;
};
#endif
diff --git a/tdeui/tests/itemcontainertest.cpp b/tdeui/tests/itemcontainertest.cpp
index 1767bec5f..c3b6d1ddc 100644
--- a/tdeui/tests/itemcontainertest.cpp
+++ b/tdeui/tests/itemcontainertest.cpp
@@ -1,5 +1,5 @@
/*
* Tests the item container widgets KIconView, KListView, KListBox
*
* Copyright (c) 2000 by Michael Reiher <michael.reiher@gmx.de>
*
@@ -16,12 +16,12 @@
#include <tqcheckbox.h>
#include <tqlabel.h>
-#include <kapplication.h>
-#include <kglobal.h>
-#include <kconfig.h>
+#include <tdeapplication.h>
+#include <tdeglobal.h>
+#include <tdeconfig.h>
#include <kiconview.h>
-#include <klistview.h>
-#include <klistbox.h>
+#include <tdelistview.h>
+#include <tdelistbox.h>
#include "itemcontainertest.h"
@@ -54,7 +54,7 @@ static const char * item_xpm[] = {
" ...... "};
-KApplication *app;
+TDEApplication *app;
TopLevel::TopLevel(TQWidget *parent, const char *name)
: TQWidget(parent, name)
@@ -88,25 +88,25 @@ TopLevel::TopLevel(TQWidget *parent, const char *name)
m_plblItem = new TQLabel( gbItem );
vBox->addWidget( gbItem );
- TQButtonGroup* bgListView = new TQButtonGroup( 1, Qt::Horizontal, "KListView", this);
+ TQButtonGroup* bgListView = new TQButtonGroup( 1, Qt::Horizontal, "TDEListView", this);
TQCheckBox* cbListView = new TQCheckBox("Single Column", bgListView);
vBox->addWidget( bgListView );
connect( cbListView, TQT_SIGNAL( toggled( bool ) ),
this, TQT_SLOT( slotToggleSingleColumn( bool ) ) );
- KGlobal::config()->reparseConfiguration();
+ TDEGlobal::config()->reparseConfiguration();
//Create IconView
- TQGroupBox* gbIconView = new TQGroupBox( 1, Qt::Horizontal, "KIconView", this);
- m_pIconView = new KIconView( gbIconView );
+ TQGroupBox* gbIconView = new TQGroupBox( 1, Qt::Horizontal, "TDEIconView", this);
+ m_pIconView = new TDEIconView( gbIconView );
hBox->addWidget( gbIconView );
hBox->addSpacing( 5 );
connect( m_pIconView, TQT_SIGNAL( executed( TQIconViewItem* ) ),
this, TQT_SLOT( slotIconViewExec( TQIconViewItem* ) ) );
//Create ListView
- TQGroupBox* gbListView = new TQGroupBox( 1, Qt::Horizontal, "KListView", this);
- m_pListView = new KListView( gbListView );
+ TQGroupBox* gbListView = new TQGroupBox( 1, Qt::Horizontal, "TDEListView", this);
+ m_pListView = new TDEListView( gbListView );
m_pListView->addColumn("Item");
m_pListView->addColumn("Text");
hBox->addWidget( gbListView );
@@ -115,8 +115,8 @@ TopLevel::TopLevel(TQWidget *parent, const char *name)
this, TQT_SLOT( slotListViewExec( TQListViewItem* ) ) );
//Create ListBox
- TQGroupBox* gbListBox = new TQGroupBox( 1, Qt::Horizontal, "KListBox", this);
- m_pListBox = new KListBox( gbListBox );
+ TQGroupBox* gbListBox = new TQGroupBox( 1, Qt::Horizontal, "TDEListBox", this);
+ m_pListBox = new TDEListBox( gbListBox );
hBox->addWidget( gbListBox );
connect( m_pListBox, TQT_SIGNAL( executed( TQListBoxItem* ) ),
this, TQT_SLOT( slotListBoxExec( TQListBoxItem* ) ) );
@@ -151,24 +151,24 @@ void TopLevel::slotSwitchMode( int id )
switch( id ) {
case TopLevel::NoSelection:
- m_pIconView->setSelectionMode( KIconView::NoSelection );
+ m_pIconView->setSelectionMode( TDEIconView::NoSelection );
m_pListView->setSelectionMode( TQListView::NoSelection );
- m_pListBox->setSelectionMode( KListBox::NoSelection );
+ m_pListBox->setSelectionMode( TDEListBox::NoSelection );
break;
case TopLevel::Single:
- m_pIconView->setSelectionMode( KIconView::Single );
+ m_pIconView->setSelectionMode( TDEIconView::Single );
m_pListView->setSelectionMode( TQListView::Single );
- m_pListBox->setSelectionMode( KListBox::Single );
+ m_pListBox->setSelectionMode( TDEListBox::Single );
break;
case TopLevel::Multi:
- m_pIconView->setSelectionMode( KIconView::Multi );
+ m_pIconView->setSelectionMode( TDEIconView::Multi );
m_pListView->setSelectionMode( TQListView::Multi );
- m_pListBox->setSelectionMode( KListBox::Multi );
+ m_pListBox->setSelectionMode( TDEListBox::Multi );
break;
case TopLevel::Extended:
- m_pIconView->setSelectionMode( KIconView::Extended );
+ m_pIconView->setSelectionMode( TDEIconView::Extended );
m_pListView->setSelectionMode( TQListView::Extended );
- m_pListBox->setSelectionMode( KListBox::Extended );
+ m_pListBox->setSelectionMode( TDEListBox::Extended );
break;
default:
Q_ASSERT(0);
@@ -177,7 +177,7 @@ void TopLevel::slotSwitchMode( int id )
void TopLevel::slotIconViewExec( TQIconViewItem* item )
{
- m_plblWidget->setText("KIconView");
+ m_plblWidget->setText("TDEIconView");
m_plblSignal->setText("executed");
if( item )
m_plblItem->setText( item->text() );
@@ -187,7 +187,7 @@ void TopLevel::slotIconViewExec( TQIconViewItem* item )
void TopLevel::slotListViewExec( TQListViewItem* item )
{
- m_plblWidget->setText("KListView");
+ m_plblWidget->setText("TDEListView");
m_plblSignal->setText("executed");
if( item )
m_plblItem->setText( item->text(0) );
@@ -197,7 +197,7 @@ void TopLevel::slotListViewExec( TQListViewItem* item )
void TopLevel::slotListBoxExec( TQListBoxItem* item )
{
- m_plblWidget->setText("KListBox");
+ m_plblWidget->setText("TDEListBox");
m_plblSignal->setText("executed");
if( item )
m_plblItem->setText( item->text() );
@@ -212,7 +212,7 @@ void TopLevel::slotToggleSingleColumn( bool b )
int main( int argc, char ** argv )
{
- app = new KApplication ( argc, argv, "ItemContainerTest" );
+ app = new TDEApplication ( argc, argv, "ItemContainerTest" );
TopLevel *toplevel = new TopLevel(0, "itemcontainertest");
@@ -1,5 +1,5 @@
/*
-* Tests the item container widgets KIconView, KListView, KListBox
+* Tests the item container widgets TDEIconView, TDEListView, TDEListBox
*
* Copyright (c) 2000 by Michael Reiher <michael.reiher@gmx.de>
diff --git a/tdeui/tests/twindowtest.cpp b/tdeui/tests/twindowtest.cpp
index 02b47c2d8..77e01d289 100644
--- a/tdeui/tests/twindowtest.cpp
+++ b/tdeui/tests/twindowtest.cpp
@@ -9,36 +9,36 @@
#include <stdlib.h>
#include <kstatusbar.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <kcombobox.h>
#include <khelpmenu.h>
-#include <kcmdlineargs.h>
-#include <kmenubar.h>
-#include <ktoolbarradiogroup.h>
+#include <tdecmdlineargs.h>
+#include <tdemenubar.h>
+#include <tdetoolbarradiogroup.h>
#include <kiconloader.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
#include <tqmultilineedit.h>
#include "twindowtest.h"
-#include <kglobal.h>
+#include <tdeglobal.h>
//#include <dclock.h>
/*
- Ok this is a constructor of our top widget. It inherits KMainWindow.
+ Ok this is a constructor of our top widget. It inherits TDEMainWindow.
In constructor wi will create all of our interface elements:
menubar, toolbar(s), statusbar, and main widget. Non of those
interface is obligatory, i.e. you don't have to use menubar,
toolbars or statusbar if you don't want to. Theoreticly, you
don't need even main widget (but in that case, you'll get blank
- KMainWindow).
+ TDEMainWindow).
*/
static int itemId = 0;
testWindow::testWindow (TQWidget *parent, const char *name)
- : KMainWindow (parent,name)
+ : TDEMainWindow (parent,name)
{
ena=false;
setCaption("test window");
@@ -55,7 +55,7 @@ setAutoSaveSettings();
menuBar->insertItem ("&File", fileMenu);
// We insert item "Exit" with accelerator ALT-Q, and connect
// it to application's exit-slot.
- fileMenu->insertItem ("&Exit", KApplication::kApplication(),
+ fileMenu->insertItem ("&Exit", TDEApplication::kApplication(),
TQT_SLOT( quit() ), ALT + Key_Q );
// Another popup...
@@ -148,12 +148,12 @@ setAutoSaveSettings();
// Now add another button and align it right
pix = BarIcon("exit");
- tb->insertButton(pix, 6, TQT_SIGNAL(clicked()), KApplication::kApplication(),
+ tb->insertButton(pix, 6, TQT_SIGNAL(clicked()), TDEApplication::kApplication(),
TQT_SLOT( quit() ), true, "Exit");
tb->alignItemRight (6);
// Another toolbar
- tb1 = new KToolBar(this, TQMainWindow::DockTop); // this one is normal and has separators
+ tb1 = new TDEToolBar(this, TQMainWindow::DockTop); // this one is normal and has separators
pix = BarIcon("filenew");
@@ -194,7 +194,7 @@ setAutoSaveSettings();
tb1->setToggle(7);
//Create
- rg = new KToolBarRadioGroup (tb1);
+ rg = new TDEToolBarRadioGroup (tb1);
rg->addButton(4);
rg->addButton(5);
@@ -230,7 +230,7 @@ setAutoSaveSettings();
//... and main widget
setCentralWidget (widget);
// This is not strictly related to toolbars, menubars or KMainWindow.
// Setup popup for completions
completions = new TQPopupMenu;
@@ -328,7 +328,7 @@ void testWindow::slotCompletion()
completions->popup(TQCursor::pos()); // This popup should understunf keys up and down
/* This is just an example. KLined automatically sets cursor at end of string
- when ctrl-d or ctrl-s is pressed. KToolBar will also put cursor at end of text in Lined
+ when ctrl-d or ctrl-s is pressed. TDEToolBar will also put cursor at end of text in Lined
after inserting text with setLinedText (...).
*/
@@ -408,7 +408,7 @@ void testWindow::slotExit ()
{
TQPixmap pix;
pix = BarIcon("exit");
- tb->insertButton(pix, 6, TQT_SIGNAL(clicked()), KApplication::kApplication(),
+ tb->insertButton(pix, 6, TQT_SIGNAL(clicked()), TDEApplication::kApplication(),
TQT_SLOT( quit() ), true, "Exit");
tb->alignItemRight (6);
exitB = true;
@@ -502,9 +502,9 @@ void testWindow::slotMakeItem3Current()
int main( int argc, char *argv[] )
{
int i;
- KCmdLineArgs::init(argc, argv, "KWindowTest", "description", "version");
+ TDECmdLineArgs::init(argc, argv, "KWindowTest", "description", "version");
- KApplication *myApp = new KApplication();
+ TDEApplication *myApp = new TDEApplication();
testWindow *test = new testWindow;
myApp->setMainWidget(test);
@@ -230,7 +230,7 @@ setAutoSaveSettings();
//... and main widget
setCentralWidget (widget);
- // This is not strictly related to toolbars, menubars or KMainWindow.
+ // This is not strictly related to toolbars, menubars or TDEMainWindow.
// Setup popup for completions
completions = new TQPopupMenu;